@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ialign" "0.5.0"
-  "Visual align-regexp."
+(define-package "ialign" "20251020.2046"
+  "Interactive align-regexp."
   '((emacs "25.1"))
   :url "https://github.com/mkcms/interactive-align"
-  :commit "fd1ad6bae74961e0b6bdf0bd15e6d9679186aaed"
-  :revdesc "v0.5.0-0-gfd1ad6bae749"
+  :commit "6ed18b077af4946233c140a63465ea1b54654ede"
+  :revdesc "6ed18b077af4"
   :keywords '("tools" "editing" "align" "interactive")
   :authors '(("Michał Krzywkowski" . "k.michal@zoho.com"))
   :maintainers '(("Michał Krzywkowski" . "k.michal@zoho.com")))
